@@ -101,7 +101,7 @@ static void AbiCommand_RemoveFromMethods ()
 
   // remove the edit method
   EV_EditMethodContainer* pEMC = pApp->getEditMethodContainer() ;
-  EV_EditMethod * pEM = ev_EditMethod_lookup ( "AbiCOmmand_invoke" ) ;
+  EV_EditMethod * pEM = ev_EditMethod_lookup ( "AbiCommand_invoke" ) ;
   pEMC->removeEditMethod ( pEM ) ;
   DELETEP( pEM ) ;
 }
